@@ -347,13 +347,18 @@ sub fetchId {
 # @return true if the session was found, false else
 sub retrieveSession {
     my ( $class, $id ) = @_;
+    my $now = time();
 
     # 1. Search if the user was the same as previous (very efficient in
     # persistent connection).
-    return 1
-      if (  defined $datas->{_session_id}
+    if (    defined $datas->{_session_id}
         and $id eq $datas->{_session_id}
-        and ( time() - $ntsv->{datasUpdate} < 60 ) );
+        and ( $now - $ntsv->{datasUpdate} < 60 ) )
+    {
+        Lemonldap::NG::Handler::Main::Logger->lmLog(
+            "Get session $id from Handler internal cache", 'debug' );
+        return 1;
+    }
 
     # 2. Get the session from cache or backend
     my $apacheSession = Lemonldap::NG::Common::Session->new(
@@ -371,10 +376,12 @@ sub retrieveSession {
 
         $datas = $apacheSession->data;
 
+        Lemonldap::NG::Handler::Main::Logger->lmLog( "Get session $id",
+            'debug' );
+
         # Update the session to notify activity, if necessary
-        if ( $tsv->{timeoutActivity} and ( time() - $datas->{_lastSeen} < 60 ) )
-        {
-            $apacheSession->update( { '_lastSeen' => time } );
+        if ( $tsv->{timeoutActivity} and ( $now - $datas->{_lastSeen} > 60 ) ) {
+            $apacheSession->update( { '_lastSeen' => $now } );
 
             if ( $apacheSession->error ) {
                 Lemonldap::NG::Handler::Main::Logger->lmLog(
@@ -382,9 +389,13 @@ sub retrieveSession {
                 Lemonldap::NG::Handler::Main::Logger->lmLog(
                     $apacheSession->error, 'error' );
             }
+            else {
+                Lemonldap::NG::Handler::Main::Logger->lmLog(
+                    "Update _lastSeen with $now", 'debug' );
+            }
         }
 
-        $datasUpdate = time();
+        $ntsv->{datasUpdate} = $now;
         return 1;
     }
     else {
